@@ -4,17 +4,15 @@ use strict;
 use warnings;
 use 5.012;
 use Cwd qw/abs_path/;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ( $pkg, @new ) = @_;
     my %args = scalar @new == 1 ? @{ shift @new } : @new;
     $args{file_name} //= 'test';
     $args{find}      //= 'css';
-    my @caller = caller();
-    $args{abs_path} = abs_path(
-         substr($caller[1], 0, rindex($caller[1], 0), '/')
-    );
+    my $path = abs_path( [caller()]->[1] );
+    $args{abs_path} = substr($path, 0, rindex($path, '/'));
     if ($args{write_dir}) {
 	$args{write_dir} = sprintf "%s/%s", $args{abs_path}, $args{write_dir};
 	unless(-d $args{write_dir}) {
@@ -54,6 +52,7 @@ sub write_file {
 
 sub make_replacements {
     my $regx = join "|", map { quotemeta($_) } keys %{ $_[1] };
+    return $_[2] unless $regx;
     $_[2] =~ s/($regx)/$_[1]->{$1}/g;
     ( !$_[2] =~ m/\n$/ ) and $_[2] .= "\n";
     return $_[2];
@@ -117,7 +116,7 @@ Hazy - A simple, minimalistic CSS framework.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -129,10 +128,10 @@ Version 0.02
     use Hazy;
 
     Hazy->new(
-        read_dir => 't/odea', 
+        read_dir => 't/vanilla/', 
         write_dir => 'static/css', 
-        file_name => 'shiny', 
-        find => 'meh', # default is css
+        file_name => 'vanilla', 
+        find => 'high', # default is css
     )->process();
 
     1;
